@@ -1,6 +1,6 @@
 /* 
  *    Programmed By: Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
- *    Copyright 2014 (c)
+ *    Copyright 2014, 2016 (c)
  * 
  *    file: strings.c
  *    This file is part of the GnuDOS project.
@@ -21,6 +21,25 @@
 #include "strings.h"
 #include "stdlib.h"
 static str _string;
+static str _base_of_string = (str)NULL;
+
+int __do_indexof(str string, char chr, int reverse)
+{
+  if(!string || string[0] == '\0') return -1;	//make sure it is not NULL
+  if(_base_of_string)
+  {
+	free(_base_of_string);
+	_base_of_string = (str)NULL;
+  }
+  _string = (str) malloc(strlen(string)+1);
+  if(!_string) return -1;
+  strcpy(_string, string);
+  _base_of_string = _string;
+  
+  str j = reverse ? strrchr(string, chr) : strchr(string, chr);
+  if(j) {_string += (++j)-_string; return j-string; }
+  return -1;
+}
 
 /********************************************
  * returns zero-based index of chr in string.
@@ -28,19 +47,7 @@ static str _string;
  * ******************************************/
 int indexof(str string, char chr) 
 {
-  if(!string) return -1;	//make sure it is not NULL
-  if(_string) free(_string);
-  _string = (str) malloc(strlen(string));
-  strcpy(_string, string);
-  
-  if(chr >= 32 && chr <= 126) 
-  {//make sure it is alphanumeric
-    str j;
-    j = strchr(string, chr);
-    if(j) {_string += (++j)-_string; return j-string; }
-    else return -1;
-  }
-  return -1;
+	return __do_indexof(string, chr, 0);
 }
 
 /********************************************
@@ -49,19 +56,7 @@ int indexof(str string, char chr)
  * ******************************************/
 int lindexof(str string, char chr) 
 {
-  if(!string) return -1;	//make sure it is not NULL
-  //if(_string) free(_string); 
-  _string = (str) malloc(strlen(string));
-  strcpy(_string, string);
-  
-  if(chr >= 32 && chr <= 126) 
-  {//make sure it is alphanumeric
-    str j;
-    j = strrchr(string, chr);
-    if(j) return j-string;
-    else return -1;
-  }
-  return -1;
+	return __do_indexof(string, chr, 1);
 }
 
 /************************************************
@@ -73,13 +68,8 @@ int nindexof(char chr)
 {
   if(!_string) return -1;	//make sure it is not NULL
   
-  if(chr >= 32 && chr <= 126) 
-  {//make sure it is alphanumeric
-    str j;
-    j = strchr(_string, chr);
-    if(j) { return j-_string; _string = ++j; }
-    else return -1;
-  }
+  str j = strchr(_string, chr);
+  if(j) { return j-_string; _string = ++j; }
   return -1;
 }
 
@@ -104,10 +94,10 @@ str nsubstr(str string, int start, int length)
 {
   if(!string) return NULL;	//make sure it is not NULL
   if(start < 0 || start >= strlen(string)) return NULL;
-  if(length < 0 || length >= strlen(string)) return NULL;
-  str _s = (str) malloc(strlen(string));
-  strcpy(_s, string);
-  _s += start;
+  if(length < 0 || length > strlen(string)) return NULL;
+  str _s = (str) malloc(length+1);
+  if(!_s) return NULL;
+  strncpy(_s, string+start, length);
   _s[length] = '\0';
   return _s;
 }
@@ -118,7 +108,8 @@ str nsubstr(str string, int start, int length)
 str uppercase(str string) 
 {
   if(!string) return NULL;
-  str _s = (str) malloc(strlen(string));
+  str _s = (str) malloc(strlen(string)+1);
+  if(!_s) return NULL;
   strcpy(_s, string);
   int i;
   for(i = 0; i < strlen(_s); i++)
@@ -133,7 +124,8 @@ str uppercase(str string)
 str lowercase(str string) 
 {
   if(!string) return NULL;
-  str _s = (str) malloc(strlen(string));
+  str _s = (str) malloc(strlen(string)+1);
+  if(!_s) return NULL;
   strcpy(_s, string);
   int i;
   for(i = 0; i < strlen(_s); i++)
@@ -149,7 +141,8 @@ str lowercase(str string)
 str ltrim(str string) 
 {
   if(!string) return NULL;
-  str _s = (str) malloc(strlen(string));
+  str _s = (str) malloc(strlen(string)+1);
+  if(!_s) return NULL;
   strcpy(_s, string);
   int i;
   for(i = 0; i < strlen(_s); i++)
@@ -167,7 +160,8 @@ str ltrim(str string)
 str rtrim(str string) 
 {
   if(!string) return NULL;
-  str _s = (str) malloc(strlen(string));
+  str _s = (str) malloc(strlen(string)+1);
+  if(!_s) return NULL;
   strcpy(_s, string);
   int i;
   for(i = strlen(_s)-1; i >= 0; i--)
@@ -185,7 +179,8 @@ str rtrim(str string)
 str trim(str string) 
 {
   if(!string) return NULL;
-  str _s = (str) malloc(strlen(string));
+  str _s = (str) malloc(strlen(string)+1);
+  if(!_s) return NULL;
   strcpy(_s, string);
   int i;
   //trim the left side
