@@ -1,6 +1,6 @@
 /* 
  *    Programmed By: Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
- *    Copyright 2014 (c)
+ *    Copyright 2014, 2015 (c)
  * 
  *    file: ukbd.c
  *    This file is part of the GnuDOS project.
@@ -29,18 +29,20 @@
 #include <stdlib.h>
 #include <string.h>	//for memset()
 
-
+/*
+ * Gets key presses under console (i.e. not under X).
+ */
 char *ugetKeyUnderConsole()
 {
     char buf[5];
-    int res;//, i = 0;
-    //char uc[5];
+    int res;
     int bytes = 0;
     memset(uc, 0, 5);//set the unicode buffer into zeroes
-//sleep(1);
     while (1) 
     {
       res = read(0, &buf[0], 1);
+      if(res == -1) { uc[0] = -1; return uc; }
+      
       //fprintf(stdout, "%c", buf[0]);
       if ((buf[0] & mask[0]) == mask[0]) bytes++;
       if ((buf[0] & mask[1]) == mask[1]) bytes++;
@@ -107,86 +109,28 @@ char *ugetKeyUnderConsole()
 	case 0x1d : CTRL = 1; uc[0] = 0; break;
 	case 0x38 : ALT = 1; uc[0] = 0; break;
 	case 0x39 : uc[0] = SPACE_KEY; break;
-	//scancodes for keyreleases
-/*	case -126: printf("1 was released"); break;
-	case -125: printf("2 was released"); break;
-	case -124: printf("3 was released"); break;
-	case -123: printf("4 was released"); break;
-	case -122: printf("5 was released"); break;
-	case -121: printf("6 was released"); break;
-	case -120: printf("7 was released"); break;
-	case -119: printf("8 was released"); break;
-	case -118: printf("9 was released"); break;
-	case -117: printf("0 was released"); break;
-	case -116: printf("- was released"); break;
-	case -115: printf("= was released"); break;
-	case -114: printf("BKSP was released"); break;
-	case -113: printf("TAB was released"); break;
-	case -112: printf("q was released"); break;
-	case -111: printf("w was released"); break;
-	case -110: printf("e was released"); break;
-	case -109: printf("r was released"); break;
-	case -108: printf("t was released"); break;
-	case -107: printf("y was released"); break;
-	case -106: printf("u was released"); break;
-	case -105: printf("i was released"); break;
-	case -104: printf("o was released"); break;
-	case -103: printf("p was released"); break;
-	case -102: printf("[ was released"); break;
-	case -101: printf("] was released"); break;
-	case -100: printf("ENTER was released"); break;
-	case -98: printf("a was released"); break;
-	case -97: printf("s was released"); break;
-	case -96: printf("d was released"); break;
-	case -95: printf("f was released"); break;
-	case -94: printf("g was released"); break;
-	case -93: printf("h was released"); break;
-	case -92: printf("j was released"); break;
-	case -91: printf("k was released"); break;
-	case -90: printf("l was released"); break;
-	case -89: printf("; was released"); break;
-	case -88: printf("' was released"); break;
-	case -87: printf("` was released"); break;
-	case -85: printf("\\ was released"); break;
-	case -70: printf("CAPS was released"); break;
-	case -84: printf("z was released"); break;
-	case -83: printf("x was released"); break;
-	case -82: printf("c was released"); break;
-	case -81: printf("v was released"); break;
-	case -80: printf("b was released"); break;
-	case -79: printf("n was released"); break;
-	case -78: printf("m was released"); break;
-	case -77: printf(", was released"); break;
-	case -76: printf(". was released"); break;
-	case -75: printf("/ was released"); break;
-	case -42: printf("< was released"); break;*/
 	case -86: SHIFT = 0; uc[0] = SHIFT_UP; break;
 	case -99: CTRL = 0; uc[0] = 0; break;
 	case -72: ALT = 0; uc[0] = 0; break;
-//	case -71: printf("SPACE was released"); break;
 	case -74: SHIFT = 0; uc[0] = SHIFT_UP; break;
-	case -32: res = read(0, &buf[0], 1);
-//		printf(" %d", buf[0]);
-		if(buf[0] == 73) { uc[0] = PGUP_KEY; break; }
-		if(buf[0] == 81) { uc[0] = PGDOWN_KEY; break; }
-		if(buf[0] == 72) { uc[0] = UP_KEY; break; }
-		if(buf[0] == 71) { uc[0] = HOME_KEY; break; }
-		if(buf[0] == 79) { uc[0] = END_KEY; break; }
-		if(buf[0] == 82) { uc[0] = INS_KEY; break; }
-		if(buf[0] == 83) { uc[0] = DEL_KEY; break; }
-//		if(buf[0] == -56) printf("UP was released");
-		if(buf[0] == 75) { uc[0] = LEFT_KEY; break; }
-//		if(buf[0] == -53) printf("LF was released");
-		if(buf[0] == 80) { uc[0] = DOWN_KEY; break; }
-//		if(buf[0] == -48) printf("DN was released");
-		if(buf[0] == 77) { uc[0] = RIGHT_KEY; break; }
-//		if(buf[0] == -51) printf("RT was released");
-		if(buf[0] == 29) { CTRL = 1; uc[0] = 0; break; }
-		if(buf[0] == -99) { CTRL = 0; uc[0] = 0; break; }
-		if(buf[0] == 56) { ALT = 1; uc[0] = 0; break; }
-		if(buf[0] == -72) { ALT = 0; uc[0] = 0; break; }
-	
-	//default: printf("%c(%d)", buf[0], buf[0]); break;
+	case -32:
+	  res = read(0, &buf[0], 1);
+	  //		printf(" %d", buf[0]);
+	  if(buf[0] == 73) { uc[0] = PGUP_KEY; break; }
+	  if(buf[0] == 81) { uc[0] = PGDOWN_KEY; break; }
+	  if(buf[0] == 72) { uc[0] = UP_KEY; break; }
+	  if(buf[0] == 71) { uc[0] = HOME_KEY; break; }
+	  if(buf[0] == 79) { uc[0] = END_KEY; break; }
+	  if(buf[0] == 82) { uc[0] = INS_KEY; break; }
+	  if(buf[0] == 83) { uc[0] = DEL_KEY; break; }
+	  if(buf[0] == 75) { uc[0] = LEFT_KEY; break; }
+	  if(buf[0] == 80) { uc[0] = DOWN_KEY; break; }
+	  if(buf[0] == 77) { uc[0] = RIGHT_KEY; break; }
+	  if(buf[0] == 29) { CTRL = 1; uc[0] = 0; break; }
+	  if(buf[0] == -99) { CTRL = 0; uc[0] = 0; break; }
+	  if(buf[0] == 56) { ALT = 1; uc[0] = 0; break; }
+	  if(buf[0] == -72) { ALT = 0; uc[0] = 0; break; }
+	  
 	default:
 	  uc[0] = buf[0];
 	  int i = 0;
@@ -204,7 +148,9 @@ char *ugetKeyUnderConsole()
 }
 
 
-
+/*
+ * Gets key presses under X.
+ */
 char *ugetKeyUnderX()
 {
   int c;
@@ -337,7 +283,9 @@ char *ugetKeyUnderX()
 }
 
 
-
+/*
+ * Gets the next key press from buffer.
+ */
 char *ugetKey()
 {
 	if(X_IS_RUNNING) return ugetKeyUnderX();
