@@ -24,7 +24,10 @@
 #include "../corelib/dialogs.h"
 #include "form.h"
 
+#ifndef __BOOL_DEFINED_
+#define __BOOL_DEFINED_
 typedef int bool;
+#endif
 void showAboutDialogBox();
 void showQuickReference();
 void showReadMe();
