@@ -37,13 +37,13 @@ void makeProject()
     char *dir = (char *) malloc(MAX_FORM_FILE_NAME_LEN);
     strncpy(dir, form_file_name, j);
     strcat(dir, "\0");
-    chdir(dir);
+    j = chdir(dir);
     free(dir);
   }
   
   FILE *file;
   int i, overwrite_all = 0;;
-  if(file = fopen("main.c", "r")) 
+  if((file = fopen("main.c", "r")))
   {
     int i = msgBox("File:\nmain.c\nalready exists. Overwrite?", YES|NO|ALL,
 		   CONFIRM);
@@ -101,7 +101,7 @@ void makeProject()
 
 write_header_file:
   if(!overwrite_all)
-    if(file = fopen("fog_header.h", "r")) 
+    if((file = fopen("fog_header.h", "r")))
     {
       int i = msgBox("File:\nfog_header.h\nalready exists. Overwrite?", 
 		     YES|NO|ALL, CONFIRM);
@@ -172,7 +172,7 @@ write_header_file:
 
 write_design_file:
   if(!overwrite_all)
-    if(file = fopen("form_design.c", "r")) 
+    if((file = fopen("form_design.c", "r")))
     {
       int i = msgBox("File:\nform_design.c\nalready exists. Overwrite?", 
 		     YES|NO|ALL, CONFIRM);
@@ -193,7 +193,7 @@ write_design_file:
     fprintf(file, "void init_form() {\n");
     fprintf(file, "\tFORM_WIDTH = %d;\n", FORM_WIDTH);
     fprintf(file, "\tFORM_HEIGHT = %d;\n", FORM_HEIGHT);
-    fprintf(file, "\tFORM_TITLE = (char *) malloc(%d);\n", strlen(FORM_TITLE));
+    fprintf(file, "\tFORM_TITLE = (char *) malloc(%d);\n", (int)strlen(FORM_TITLE));
     fprintf(file, "\tstrcpy(FORM_TITLE, \"%s\");\n", FORM_TITLE);
     //fprintf(file, "\ttotal_form_tools = %d;\n\n", total_form_tools);
     fprintf(file, "\tFG_COLOR[COLOR_WINDOW] = %d;\n", FG_COLOR[COLOR_WINDOW]);
@@ -214,10 +214,10 @@ write_design_file:
     for(i = 0; i < total_form_tools; i++) 
     {
       fprintf(file, "\tform_tool[%d] = (char *) malloc(%d);\n", i, 
-	      strlen(form_tool[i]));
+	      (int)strlen(form_tool[i]));
       fprintf(file, "\tstrcpy(form_tool[%d], \"%s\");\n", i, form_tool[i]);
       fprintf(file, "\tform_tool_text[%d] = (char *) malloc(%d);\n", 
-	      i, strlen(form_tool_text[i]));
+	      i, (int)strlen(form_tool_text[i]));
       fprintf(file, "\tstrcpy(form_tool_text[%d], \"%s\");\n", 
 	      i, form_tool_text[i]);
       fprintf(file, "\ttool_pos[%d].x = %d;\n", i, tool_pos[i].x);
