@@ -28,6 +28,13 @@
 #include <sys/stat.h>
 #include <string.h>
 #include <unistd.h>
+#include <errno.h>
+
+#define DIR_RETURN_ERROR()		\
+{					\
+    msgBox(strerror(errno), OK, ERROR);	\
+    return 0;				\
+}
 
 static int one(const struct dirent *unused) 
 {
@@ -42,10 +49,15 @@ int scanDir(char *dir)
   struct dirent **eps;
   struct stat st;
 
-  chdir(dir);
-  cwd = getcwd(NULL, 0);
+  int x = chdir(dir);
+  if(x == -1) DIR_RETURN_ERROR();
   
- lstat(dir,&st);
+  cwd = getcwd(NULL, 0);
+  if(cwd == NULL) DIR_RETURN_ERROR();
+  
+  x = lstat(dir, &st);
+  if(x == -1) DIR_RETURN_ERROR();
+ 
  if(S_ISDIR(st.st_mode)) 
  {
   n = scandir(dir, &eps, one, alphasort);
@@ -54,7 +66,9 @@ int scanDir(char *dir)
     int cnt;
     for(cnt = 0; cnt < n; ++cnt) 
     {
-      lstat(eps[cnt]->d_name,&st);
+      x = lstat(eps[cnt]->d_name,&st);
+      if(x == -1) DIR_RETURN_ERROR();
+      
       if(S_ISDIR(st.st_mode)) 
       {
 	if(strcmp(eps[cnt]->d_name, ".") == 0) //ignore "."
@@ -86,6 +100,7 @@ int scanDir(char *dir)
   else 
   {	//end inner if
     char *tmp = (char *) malloc(strlen(dir)+21);
+    if(!tmp) { msgBox("Insufficient memory", OK, ERROR); return 0; }
     sprintf(tmp, "Error opening dir:\n%s", dir);
     strcat(tmp, "\0");
     msgBox(tmp, OK, ERROR);
@@ -107,11 +122,12 @@ int scanDir(char *dir)
  * **************************************/
 void refreshDirView() 
 {
- //drawBox(x, y, h, w, " Select file ", YES);	//draw left sub-window
  if(strlen(cwd) > w-y-5) 
  {
    char *tmp;
    tmp = (char *) malloc(w-y+1);
+   if(!tmp) { msgBox("Insufficient memory", OK, ERROR); return; }
+   
    int i, k, j = w-y-5;
    for(i = strlen(cwd), k = j; k > 1; i--, k--) tmp[k] = cwd[i];
    tmp[0] = '.';
@@ -131,7 +147,6 @@ void refreshDirView()
     printf("[ENTER]: Open dir/file  [ARROWS]: Navigate  [ESC]: Cancel");
  fprintf(stdout, "\e[%d;%dH", h-2, y+1);
  printf("File: ");
- //setScreenColors(WHITE, BGBLUE);
  
  int i = firstVisDir;
  int j = 0; int k = 0;
@@ -142,19 +157,16 @@ void refreshDirView()
       if((i-firstVisDir) == selectedDir) 
       {
 	setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], BG_COLOR[COLOR_HIGHLIGHT_TEXT]);
-	//setScreenColors(BLUE, BGWHITE);
 	fprintf(stdout, "\x1b[%d;%dH[%s]", (j >= numVisDirs) ? j-numVisDirs+3:j+3,
 				       (j >= numVisDirs) ? x+MAX_DIR_NAME_LEN+1:x+1,
 				       dirs[i]);
 	curX = (j >= numVisDirs) ? j-numVisDirs+3 : j+3;
-	//curX = i+3;
 	curY = (j >= numVisDirs) ? x+MAX_DIR_NAME_LEN+strlen(dirs[i])
 				  : x+strlen(dirs[i]); curY += 3;
       } 
       else 
       {
-	setScreenColors(FG_COLOR[COLOR_HBUTTONS], BG_COLOR[COLOR_WINDOW]);
-	//setScreenColors(GREEN, BGBLUE);
+	setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	fprintf(stdout, "\x1b[%d;%dH[%s]", (j >= numVisDirs) ? j-numVisDirs+3:j+3,
 				       (j >= numVisDirs) ? x+MAX_DIR_NAME_LEN+1:x+1,
 				       dirs[i]);
@@ -167,26 +179,22 @@ void refreshDirView()
  {
     if(firstVisDir > totalDirs) j = firstVisDir-totalDirs;
     else j = 0;
-    //i -= j;
     
     while(j < totalFiles) 
     {
       if((i-firstVisDir) == selectedDir) 
       {
 	setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], BG_COLOR[COLOR_HIGHLIGHT_TEXT]);
-	//setScreenColors(BLUE, BGWHITE);
 	fprintf(stdout, "\x1b[%d;%dH%s", (k >= numVisDirs) ? k-numVisDirs+3:k+3,
 				       (k >= numVisDirs) ? x+MAX_DIR_NAME_LEN+1:x+1,
 				       files[j]);
 	curX = (j >= numVisDirs) ? j-numVisDirs+3 : j+3;
-	//curX = i+3;
 	curY = (j >= numVisDirs) ? x+MAX_DIR_NAME_LEN+strlen(files[j])
 				  : x+strlen(files[j]); curY += 3;
       } 
       else 
       {
-	setScreenColors(FG_COLOR[COLOR_HBUTTONS], BG_COLOR[COLOR_WINDOW]);
-	//setScreenColors(GREEN, BGBLUE);
+	setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
 	fprintf(stdout, "\x1b[%d;%dH%s", (k >= numVisDirs) ? k-numVisDirs+3:k+3,
 				       (k >= numVisDirs) ? x+MAX_DIR_NAME_LEN+1:x+1,
 				       files[j]);
