@@ -1,35 +1,35 @@
 /* 
  *    Programmed By: Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
- *    Copyright 2014 (c)
+ *    Copyright 2014, 2015, 2016 (c)
  * 
  *    file: kbd.c
- *    This file is part of mino (Mino).
+ *    This file is part of mino.
  *
- *    mino (Mino) is free software: you can redistribute it and/or modify
+ *    mino is free software: you can redistribute it and/or modify
  *    it under the terms of the GNU General Public License as published by
  *    the Free Software Foundation, either version 3 of the License, or
  *    (at your option) any later version.
  *
- *    mino (Mino) is distributed in the hope that it will be useful,
+ *    mino is distributed in the hope that it will be useful,
  *    but WITHOUT ANY WARRANTY; without even the implied warranty of
  *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *    GNU General Public License for more details.
  *
  *    You should have received a copy of the GNU General Public License
- *    along with mino (Mino).  If not, see <http://www.gnu.org/licenses/>.
+ *    along with mino.  If not, see <http://www.gnu.org/licenses/>.
  */    
-#include "unistd.h"
-#include "linux/kd.h"
-#include "termios.h"
-#include "fcntl.h"
-#include "sys/ioctl.h"
-#include <stdlib.h>
 #include <stdio.h>
-#include "kbd.h"
 #include <stdlib.h>
 #include <string.h>	//for memset()
+#include <unistd.h>
+#include <termios.h>
+#include <fcntl.h>
+#include <linux/kd.h>
+#include <sys/ioctl.h>
+#include "kbd.h"
 
 unsigned short mask[] = {192, 224, 240};
+char uc[5];
 
 static struct termios tty_attr_old;
 static int old_keyboard_mode;
@@ -47,16 +47,15 @@ int initTerminal()
     tcgetattr(0, &tty_attr_old);
 
     /* turn off buffering, echo and key processing */
-    tty_attr = tty_attr_old;
+    tty_attr          = tty_attr_old;
     tty_attr.c_lflag &= ~(ICANON | ECHO | ISIG);
     tty_attr.c_iflag &= ~(ISTRIP | INLCR | ICRNL | IGNCR | IXON | IXOFF);
-    if((tcsetattr(0, TCSANOW, &tty_attr) == -1))
-      return 0;
+    if((tcsetattr(0, TCSANOW, &tty_attr) == -1)) return 0;
 
     if(!X_IS_RUNNING) ioctl(0, KDSKBMODE, K_RAW);
     //ioctl(0, KDSKBMODE, K_UNICODE);
-    ALT = 0; 
-    CTRL = 0; 
+    ALT   = 0; 
+    CTRL  = 0; 
     SHIFT = 0;
     return 1;
 }
@@ -82,17 +81,19 @@ char *getKeyUnderConsole()
     memset(uc, 0, 5);//set the unicode buffer into zeroes
     while (1) 
     {
-      res = read(0, &buf[0], 1);
-      if(res < 0) { uc[0] = 0; break; }
-      //fprintf(stdout, "%c[%d]", buf[0], buf[0]);
-      if ((buf[0] & mask[0]) == mask[0]) bytes++;
-      if ((buf[0] & mask[1]) == mask[1]) bytes++;
-      if ((buf[0] & mask[2]) == mask[2]) bytes++;
+        res = read(0, &buf[0], 1);
+        //fprintf(stdout, "\n***%d %c[%d]***\n", res, buf[0], buf[0]);
+        //fflush(stdout);
+        if(res < 0) { uc[0] = 0; break; }
+        //if(buf[0] == 0) continue;
+        if ((buf[0] & mask[0]) == mask[0]) bytes++;
+        if ((buf[0] & mask[1]) == mask[1]) bytes++;
+        if ((buf[0] & mask[2]) == mask[2]) bytes++;
       
 	switch (buf[0]) 
 	{
 	//scancodes for keypresses
-	case 0x01: uc[0] = ESC_KEY; break;
+	case 0x01 : uc[0] = ESC_KEY; break;
 	case 0x29 : uc[0] = SHIFT?'~':'`'; break;
 	case 0x02 : uc[0] = SHIFT?'!':'1'; break;
 	case 0x03 : uc[0] = SHIFT?'@':'2'; break;
@@ -174,6 +175,7 @@ char *getKeyUnderConsole()
 		else uc[0] = 0; break;
 
         default:
+          if(buf[0] <= 0) continue;
 	  uc[0] = buf[0];
 	  int i = 0;
 	  while(i < bytes) 
@@ -193,17 +195,15 @@ char *getKeyUnderConsole()
 
 char *getKeyUnderX()
 {
-  int c;
-  //char uc[5];
-  int bytes = 0;
-  memset(uc, 0, 5);//set the unicode buffer into zeroes
-  //uc[0] = '\0';
+    int c;
+    int bytes = 0;
+    memset(uc, 0, 5);//set the unicode buffer into zeroes
   
-  ALT = 0; CTRL = 0; SHIFT = 0;
+    ALT = 0; CTRL = 0; SHIFT = 0;
     while(1) 
     {
       c = getchar();
-      if(c < 0) continue;
+      if(c <= 0) continue;
       //printf("%c[%d]",  c, c);
       //fflush(stdout);
       //bytes = 0;
