@@ -3,20 +3,20 @@
  *    Copyright 2014, 2016 (c)
  * 
  *    file: menu.c
- *    This file is part of mino (Mino).
+ *    This file is part of mino.
  *
- *    mino (Mino) is free software: you can redistribute it and/or modify
+ *    mino is free software: you can redistribute it and/or modify
  *    it under the terms of the GNU General Public License as published by
  *    the Free Software Foundation, either version 3 of the License, or
  *    (at your option) any later version.
  *
- *    mino (Mino) is distributed in the hope that it will be useful,
+ *    mino is distributed in the hope that it will be useful,
  *    but WITHOUT ANY WARRANTY; without even the implied warranty of
  *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *    GNU General Public License for more details.
  *
  *    You should have received a copy of the GNU General Public License
- *    along with mino (Mino).  If not, see <http://www.gnu.org/licenses/>.
+ *    along with mino.  If not, see <http://www.gnu.org/licenses/>.
  */    
 
 #include <stdio.h>
@@ -615,7 +615,7 @@ do_left:
 	  } 
 	  else if(hSelect == 3) 
 	  {		//show About msgbox
-	    char *x = "Mino for GNU/Linux.\nDeveloped by Mohammed Isam,\n2014, 2015.";
+	    char *x = "Mino for GNU/Linux.\nDeveloped by Mohammed Isam,\n2014, 2015, 2016.";
 	    msgBox(x, OK, INFO);
 	  } 
 	  else if(hSelect == 2) 
@@ -663,13 +663,9 @@ do_left:
 
 void _do_show(int readme_keybindings)
 {
-  int x = 2;
-  int y = 2;
-  int w = SCREEN_W-1;
-  int h = SCREEN_H-1;
   FILE *README;
-  char buf[4096*4];	//buffer to hold data
-  int buf_len = 0;
+  char *buf;		//buffer to hold data
+  long buf_len = 0;
   
   char *file_name[] =
   {
@@ -690,72 +686,91 @@ void _do_show(int readme_keybindings)
   
   if(!(README = fopen(file1, "r"))) 
   {
-   if(!(README = fopen(file2, "r"))) 
-   {
-    msgBox(err[readme_keybindings], OK, ERROR);
-    refreshView();
-    return;
-   }
-  }
-  
-  if(!(buf_len = fread(buf, sizeof(char), sizeof(buf), README))) 
-  {
-    msgBox(err[readme_keybindings], OK, ERROR);
-    refreshView();
-    return;
-  }
-  
-  drawBox(x, y, h, w, title[readme_keybindings], YES);
-  
-  y++; x++;
-  int i = 0, j = x;
-  int l = y;
-  int lineStart[60];
-  int firstVisLine = 0;
-  int cnt = 0;
-  char *ch = (char *)malloc(5);
-  char moreLines = 1;	//used as boolean to indicate if still more lines
-  lineStart[0] = 0;
-  
-  fprintf(stdout, "\e[%d;%dH", j, l);
-  while(j < (h-x+2)) 
-  {
-    if(buf[i] == EOL) 
-    { 
-      lineStart[++cnt] = i+1;
-      l=y;
-      fprintf(stdout, "\e[%d;%dH", ++j, l); 
-    } 
-    else 
-    { 
-      if(l > (w-y+2)) 
-      {
-	lineStart[++cnt] = i;
-	l=y;
-	fprintf(stdout, "\e[%d;%dH", ++j, l);
-      } putchar(buf[i]); l++;
+    if(!(README = fopen(file2, "r"))) 
+    {
+      msgBox(err[readme_keybindings], OK, ERROR);
+      refreshView();
+      return;
     }
-    if(++i >= buf_len) break;
   }
   
-  fflush(stdout);
-  //if the output chars are less than the buffer length,
-  //it means there are more lines to the output.
-  if(i <= buf_len) 
-  {
-    goto readMore;
-  } 
-  else 
-  {
-    do {;} while(!getKey());
-    goto end;
-    return;
-  }
+  int i;
+  i = fseek(README, 0, SEEK_END);
+  buf_len = ftell(README);
+  rewind(README);
+  if(i == -1 || buf_len == -1) goto return_err;
+  buf_len += 512;
   
-readMore:
+  buf = (char *)malloc(buf_len);
+  if(!buf) goto return_err;
+  
+  int x = 3;
+  int y = 3;
+  int w = SCREEN_W-4;
+  int h = SCREEN_H-4;
+  
+  i = 0;
+  int firstVisLine = 0;
+  //int ch;
+  char moreLines = 1;	//used as boolean to indicate if still more lines
+  
+  int index = 0;
+  int inc;
+  long total_lines = 0;
+  long first_char = 0;
+  while((inc = fgetc(README)) != EOF)
+  {
+    buf[index++] = inc;
+    if(inc == '\n') { i = 0; total_lines++; }
+    else i++;
+
+    if(i == w)
+    {
+      buf[index++] = '\n';
+      buf_len++;
+      total_lines++;
+      i = 0;
+    }
+    buf_len++;
+  }
+  if(!total_lines)
+  {
+    if(index) total_lines = 1;
+    else goto return_err;
+  }
+  if(total_lines < h) moreLines = 0;
+  else moreLines = 1;
+  firstVisLine = 0;
+  first_char = 0;
+
+  
+  int lines = 0;
+read:
+  //redraw the box with its contents
+  drawBox(x-1, y-1, h+x, w+y, title[readme_keybindings], YES);
+  lines = 0;
+
+  fprintf(stdout, "\e[%d;%dH", x, y);
+  i = first_char;
+  while(i < buf_len)
+  {
+    if(buf[i] == '\n')
+    {
+      lines++;
+      fprintf(stdout, "\e[%d;%dH", x+lines, y);
+      if(lines >= h) break;
+    }
+    else putchar(buf[i]);
+    i++;
+    fflush(stdout);
+  }
+  if(firstVisLine+lines < total_lines) moreLines = 1;
+  else moreLines = 0;
+  
+
   while(1) 
   {
-    ch = getKey();
+    char *ch = getKey();
     switch(ch[0]) 
     {
       case('g'):
@@ -776,8 +791,18 @@ do_esc:
       case(UP_KEY):
 	if(GNU_DOS_LEVEL > 1) break;
 do_up:
-	if(firstVisLine == 0) break;	//can't go up--first line already
+	/* go up */
+	if(firstVisLine == 0) break;
+	i = first_char-1;
+	while(i >= 0)
+	{
+	  i--;
+	  if(buf[i] == '\n') break;
+	}
+	i++;
+	first_char = i;
 	firstVisLine--;
+	goto read;
 	break;
       case('n'):
 	if(GNU_DOS_LEVEL < 2) break;
@@ -786,44 +811,30 @@ do_up:
       case(DOWN_KEY):
 	if(GNU_DOS_LEVEL > 1) break;
 do_down:
-	if(!moreLines) break;	//reached last line
+	/* go down */
+	if(!moreLines) break;
+	i = first_char;
+	while(i < buf_len)
+	{
+	  if(buf[i] == '\n' || buf[i] == '\0') break;
+	  i++;
+	}
+	if(i < buf_len) i++;
+	first_char = i;
 	firstVisLine++;
+	goto read;
 	break;
     }	//end of switch
-    //redraw the box with its contents
-    drawBox(x-1, y-1, h, w, title[readme_keybindings], YES);
-    j = x; l = y; cnt = firstVisLine; i = lineStart[firstVisLine];
-    
-    fprintf(stdout, "\e[%d;%dH", j, l);
-    while(j < (h-x+2)) 
-    {
-     if(buf[i] == EOL) 
-     { 
-      lineStart[++cnt] = i+1;
-      l=y;
-      fprintf(stdout, "\e[%d;%dH", ++j, l); 
-     } 
-     else 
-     { 
-      if(l > (w-y+2)) 
-      {
-	lineStart[++cnt] = i;
-	l=y;
-	fprintf(stdout, "\e[%d;%dH", ++j, l);
-      } putchar(buf[i]); l++;
-     }
-     if(++i >= buf_len) break;
-    }	//end of inner while
-    if(i <= buf_len) { moreLines = 1; }
-    else { moreLines = 0; }
-    fflush(stdout);
-
   }	//end of outer while
+  
 end:
-  fclose(README);
-  drawMenuBar(2, 2, SCREEN_W-2);							//draw main menu bar
-  fflush(stdout);
-  return;
+    fclose(README);
+    return;
+return_err:
+    fclose(README);
+    msgBox(err[readme_keybindings], OK, ERROR);
+    refreshView();
+    return;
 }
 
 ////////////////////////////////////////////////////////
