@@ -33,7 +33,7 @@
 struct passwd *pass;//will be used to find the home dir
 time_t tm;
 
-char *prime_ver = "1.2";
+char *prime_ver = "1.3";
 
 extern int NEW_GNU_DOS_LEVEL;
 extern int write_config_file_defaults();
@@ -138,11 +138,11 @@ void parse_args(int argc, char **argv)
 		  NEW_GNU_DOS_LEVEL = i;
 		  break;
 		case 'v':	//show version & exit
-			printf("Prime version %s.\n", prime_ver);
+			printf("%s\n", prime_ver);
 			exit(0); break;
 		case 'h':	//show help & exit
 		  printf("Prime for GNU/Linux, Version %s\n"
-		    "By Mohammed Isam, 2013, 2014, 2015\n"
+		    "By Mohammed Isam, 2013, 2014, 2015, 2016\n"
 		    "Prime is a GNU software, part of the GnuDOS package\n"
 		    "Prime is a file manager for the GNU/Linux console/xterm.\n"
 		    "It was developed with ease of use and simplicity in mind.\n"
@@ -326,4 +326,4 @@ void parse_args(int argc, char **argv)
 	      exit(1);
 	    }
 	}
-}
\ No newline at end of file
+}
