@@ -1,6 +1,6 @@
 /* 
  *    Programmed By: Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
- *    Copyright 2013, 2014 (c)
+ *    Copyright 2013, 2014, 2015 (c)
  * 
  *    file: file.c
  *    This file is part of Prime.
@@ -28,6 +28,8 @@
 #include <unistd.h>
 #include <pwd.h>
 
+extern char *tmp, *tmp2;
+
 static int one(const struct dirent *unused) 
 {
   return 1;
@@ -49,10 +51,10 @@ void exportTreeFromCommandLine(char *d, char *f)
     exit(1);
   }
   
-  cwd = getcwd(NULL, 0);
+  //cwd = getcwd(NULL, 0);
 
   printf("Reading directory tree. Please wait..\n");
-  fprintf(file, "\nDirectory tree of '%s/':", cwd);
+  fprintf(file, "\nDirectory tree of '%s/':", d);
   scanThisDir(d, 0, 0);
   
   printf("Finished writing directory tree of '%s' to '%s'.\n", d, f);
@@ -75,11 +77,9 @@ void exportTree(int showFileNameDialogBox)
   }
   
   //check for '~'
-  char *tmp = (char *) malloc(MAX_DIR_NAME_LEN);
   strcpy(tmp, input);
   if(strchr(tmp, '~')) 
   {
-    char *tmp2 = (char *) malloc(MAX_DIR_NAME_LEN);
     strcpy(tmp2, input+((strchr(input, '~')+1)-input));
     struct passwd *pass;//will be used to find the home dir
     if((pass = getpwuid(geteuid())))
@@ -88,23 +88,19 @@ void exportTree(int showFileNameDialogBox)
     strcat(tmp, "/");
     strcat(tmp, tmp2);
     strcat(tmp, "\0");
-    free(tmp2);
   }
   if(!(file = fopen(tmp, "w"))) 
   {
     msgBox("Error opening export file. Aborting.", OK, ERROR);
     fprintf(log_file, "Error opening file '%s' to export tree of '%s'..\n", 
 	    tmp, cwd);
-    refreshFileView();
-    refreshDirView();
-    free(tmp);
+    refreshWindows();
     return;
   }
   
   fprintf(file, "\nDirectory tree of '%s/':", cwd);
-  //scanThisDir(cwd, NULL, 0);
   char *t = (char *) malloc(strlen(cwd));
-  //char t[strlen(cwd)];
+  if(!t) { msgBox("Insufficient memory", OK, ERROR); return; }
   strcpy(t, cwd);
   scanThisDir(t, 0, 1);
   free(t);
@@ -112,8 +108,9 @@ void exportTree(int showFileNameDialogBox)
   fprintf(log_file, "Exported tree of '%s' to file '%s'..\n", cwd, tmp);
   fclose(file);
 
-  chdir(cwd);
-  free(tmp);
+  int x = chdir(cwd);
+  if(x == -1) { msgBox("Error changing directory", OK, ERROR); return; }
+  //free(tmp);
   return;
 }
 
@@ -151,7 +148,9 @@ void scanThisDir(char tmp[], int level, int showProgress)
 	printf(exportingString, cnt+1, n);
       }//end if -- display progress message to user
       
-      lstat(eps[cnt]->d_name,&statbuf);
+      int z = lstat(eps[cnt]->d_name,&statbuf);
+      if(z == -1) { msgBox(strerror(errno), OK, ERROR); return; }
+      
       if(S_ISDIR(statbuf.st_mode)) 
       {
 	if(strcmp(eps[cnt]->d_name, ".") == 0 
@@ -161,17 +160,21 @@ void scanThisDir(char tmp[], int level, int showProgress)
 	//if(showProgress) fprintf(log_file, "Exporting dir: %s, cnt:%d\n", eps[cnt]->d_name, cnt);
 	
 	char *tmp2 = (char *)malloc(strlen(tmp)+strlen(eps[cnt]->d_name)+2);
+	if(!tmp2) { msgBox("Insufficient memory", OK, ERROR); return; }
 	strcpy(tmp2, tmp);
 	strcat(tmp2, "/");
 	strcat(tmp2, eps[cnt]->d_name);
 	strcat(tmp2, "\0");
 	
 	nd++;
-	chdir(tmp2);
+	int i;
+	i = chdir(tmp2);
+	if(i == -1) { msgBox("Error changing directory", OK, ERROR); return; }
 	//scanThisDir(eps[cnt]->d_name, level+4);
 	scanThisDir(tmp2, level+4, showProgress);
-	chdir("..");
+	i = chdir("..");
 	free(tmp2);
+	if(i == -1) { msgBox("Error changing directory", OK, ERROR); return; }
 	continue;
       } 
       else 
