@@ -1,6 +1,6 @@
 /* 
  *    Programmed By: Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
- *    Copyright 2013, 2014, 2015 (c)
+ *    Copyright 2013, 2014, 2015, 2016 (c)
  * 
  *    file: main.c
  *    This file is part of Prime.
@@ -39,6 +39,9 @@
 #include <pwd.h>
 #include <time.h>
 
+extern int fcloseall (void);    /* stdio.h */
+extern char * strcasestr (const char *HAYSTACK, const char *NEEDLE);    /* string.h */
+
 extern void showPropertiesDialog();
 
 char *tmp, *tmp2;
@@ -266,6 +269,7 @@ do_up:
 	print_dir_highlight(selectedDir);
        }//end if
        fprintf(stdout, "\e[3;3H");	//move cursor to point to window
+       fflush(stdout);
      } 
      else 
      {
@@ -285,6 +289,7 @@ do_up:
 	print_file_highlight(selectedFile);
        }//end if
        fprintf(stdout, "\e[3;%dH",(SCREEN_W/2)+2);//cursor to point to window
+       fflush(stdout);
      } 
      break;
    case(DOWN_KEY):
@@ -312,6 +317,7 @@ do_down:
 	print_dir_highlight(selectedDir);
        }//end if
        fprintf(stdout, "\e[3;3H");	//move cursor to point to window
+       fflush(stdout);
      } 
      else 
      {
@@ -335,6 +341,7 @@ do_down:
 	print_file_highlight(selectedFile);
        }//end if
        fprintf(stdout, "\e[3;%dH",(SCREEN_W/2)+2);//cursor to point to window
+       fflush(stdout);
      } 
      break;
    case(TAB_KEY):	//toggle active window with TAB press
@@ -348,6 +355,7 @@ do_down:
    case(ENTER_KEY):
      if(ALT) 
      {
+       if(activeWindow == FILE_WIN && strcmp(files[0], "(Empty folder)") == 0) break;
        showPropertiesDialog();
        setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
        scanDir(cwd);
@@ -361,10 +369,12 @@ do_down:
       }
       else
       {
-       if(strcmp(files[firstVisFile+selectedFile], "(Empty folder)") == 0)  break;
-       showPropertiesDialog();
-       setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
-       scanDir(cwd);
+       if(strcmp(files[0], "(Empty folder)"))
+       {
+           showPropertiesDialog();
+           setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
+           scanDir(cwd);
+       }
       }
       break;
      }
@@ -530,6 +540,7 @@ do_home:
        firstVisFile = 0;
        selectedFile = 0;
        refreshFileView();
+       fflush(stdout);
      } break;
    case(END_KEY):
      if(GNU_DOS_LEVEL > 1) break;
@@ -559,6 +570,7 @@ do_end:
 	 selectedFile = numVisFiles-1;
        }//end inner if
        refreshFileView();
+       fflush(stdout);
      }//end outer else
      break;
    case('g'):
@@ -581,7 +593,7 @@ do_end:
     {
      if(GNU_DOS_LEVEL > 4) break;
 do_exit:
-     if(1) ;
+      if(1) { ; }
       int i = msgBox("Are you sure you want to exit?", YES | NO, CONFIRM);
       if(i == YES) 
       { 	//exit gracefully
