@@ -1,6 +1,6 @@
 /* 
  *    Programmed By: Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
- *    Copyright 2013, 2014, 2015 (c)
+ *    Copyright 2013, 2014, 2015, 2016 (c)
  * 
  *    file: menu.c
  *    This file is part of Prime.
@@ -61,7 +61,8 @@ void showFileMenu(int visible)
     fprintf(stdout, "\e[7;3HPrint         ^P");
     fprintf(stdout, "\e[8;3HExit          ^Q");
     fprintf(stdout, "\e[4;18H");
-    while(!endme) 
+    fflush(stdout);
+   while(!endme) 
     {				//wait for user input
       ch = getKey();
       switch(ch) 
@@ -92,6 +93,7 @@ do_up:
 	  //highlight new selection
 	  fprintf(stdout, "\e[%d;3H%s", fSelect+4, fileMenu[fSelect]);
 	  fprintf(stdout, "\e[%d;18H", fSelect+4);
+          fflush(stdout);
 	  break;
 	case('n'):
 	  if(GNU_DOS_LEVEL < 2) break;
@@ -109,6 +111,7 @@ do_down:
 	  //highlight new selection
 	  fprintf(stdout, "\e[%d;3H%s", fSelect+4, fileMenu[fSelect]);
 	  fprintf(stdout, "\e[%d;18H", fSelect+4);
+          fflush(stdout);
 	  break;
 	//case(ALT_F_KEY)://hide file menu and return control to main program
 	case('f'):
@@ -255,6 +258,7 @@ void showEditMenu(int visible)
     }
     //fprintf( log_file, "Now in line 109 in showEditMenu()..\n" );
     fprintf(stdout, "\e[4;22H");
+    fflush(stdout);
     while(!endme) 
     {				//wait for user input
       ch = getKey();
@@ -286,6 +290,7 @@ do_up:
 	  //highlight new selection
 	  fprintf(stdout, "\e[%d;9H%s", eSelect+4, editMenu[eSelect]);
 	  fprintf(stdout, "\e[%d;22H", eSelect+4);
+          fflush(stdout);
 	  break;
 	case('n'):
 	  if(GNU_DOS_LEVEL < 2) break;
@@ -303,6 +308,7 @@ do_down:
 	  //highlight new selection
 	  fprintf(stdout, "\e[%d;9H%s", eSelect+4, editMenu[eSelect]);
 	  fprintf(stdout, "\e[%d;22H", eSelect+4);
+          fflush(stdout);
 	  break;
 	case('e'):
 	 if(ALT) 
@@ -407,6 +413,7 @@ void showOptionsMenu(int visible)
     for(i = 1; i < oTotal; i++) 
       fprintf(stdout, "\e[%d;15H%s", i+4, optionsMenu[i]);
     fprintf(stdout, "\e[4;30H");
+    fflush(stdout);
     while(!endme) 
     {				//wait for user input
       ch = getKey();
@@ -548,6 +555,7 @@ void showHelpMenu(int visible)
     for(i = 1; i < hTotal; i++) 
       fprintf(stdout, "\e[%d;24H%s", i+4, helpMenu[i]);
     fprintf(stdout, "\e[4;39H");
+    fflush(stdout);
     while(!endme) 
     {				//wait for user input
       ch = getKey();
@@ -579,6 +587,7 @@ do_up:
 	  //highlight new selection
 	  fprintf(stdout, "\e[%d;24H%s", hSelect+4, helpMenu[hSelect]);
 	  fprintf(stdout, "\e[%d;39H", hSelect+4);
+          fflush(stdout);
 	  break;
 	case('n'):
 	  if(GNU_DOS_LEVEL < 2) break;
@@ -596,6 +605,7 @@ do_down:
 	  //highlight new selection
 	  fprintf(stdout, "\e[%d;24H%s", hSelect+4, helpMenu[hSelect]);
 	  fprintf(stdout, "\e[%d;39H", hSelect+4);
+          fflush(stdout);
 	  break;
 	case('h'):
 	 if(ALT) 
@@ -649,7 +659,7 @@ do_left:
 	  else if(hSelect == 3) 
 	  {		//show About msgbox
 	    char *x = " Prime for GNU/Linux. \n Developed by "
-		      "Mohammed Isam, \n 2013, 2014, 2015.";
+		      "Mohammed Isam, \n 2013, 2014, 2015, 2016.";
 	    show_about(x);
 	  } 
 	  else if(hSelect == 2) 
@@ -670,6 +680,7 @@ do_left:
 	    fprintf(stdout, "\e[15;9HCTRL+F: Find files");
 	    fprintf(stdout, "\e[16;9HCTRL+Q: Quit the program");
 	    fprintf(stdout, "\e[17;7HPress any key to continue..");
+            fflush(stdout);
 	    do {;} while(!getKey());
 	  }
 	  refreshAll();
@@ -743,4 +754,4 @@ char *file_open_location()
     return tmp;
   }
   return NULL;
-}
\ No newline at end of file
+}
